nbwavedrom
==========

A simple package to add wavedrom (http://wavedrom.com) timing diagrams into a jupyter notebook.

Example: https://github.com/witchard/nbwavedrom/blob/master/examples/example.ipynb.

To get started simply `pip install nbwavedrom` or `pip install git+git://github.com/witchard/nbwavedrom.git`
for the development version. Then take a look at the example notebook within jupyter notebook.

The waveforms are rendered using the wavedrom-cli. Installation instructions can be found here: https://github.com/wavedrom/cli/.
